@@ -8,11 +8,12 @@
 import argparse
 import logging
 import os
-import random
 import sys
 from logging.handlers import TimedRotatingFileHandler
 
 from dbus.mainloop.glib import DBusGMainLoop
+
+
 DBusGMainLoop(set_as_default=True)
 from gi.repository.GLib import MainLoop  # noqa
 
@@ -25,8 +26,6 @@ from comitup import sysd         # noqa
 from comitup import webmgr       # noqa
 from comitup import wificheck    # noqa
 
-PERSIST_PATH = "/var/lib/comitup/comitup.json"
-CONF_PATH = "/etc/comitup.conf"
 LOG_PATH = "/var/log/comitup.log"
 
 
@@ -49,25 +48,6 @@ def deflog():
     return log
 
 
-def load_data():
-    conf = config.Config(
-                CONF_PATH,
-                defaults={
-                    'ap_name': 'comitup-<nnn>',
-                    'ap_password': '',
-                    'web_service': '',
-                    'external_callback': '/usr/local/bin/comitup-callback',
-                },
-             )
-
-    data = persist.persist(
-                PERSIST_PATH,
-                {'id': str(random.randrange(1000, 9999))},
-           )
-
-    return (conf, data)
-
-
 def check_environment(log):
     for service in ["systemd-resolved", "dnsmasq"]:
         try:
@@ -107,7 +87,7 @@ def main():
     log = deflog()
     log.info("Starting comitup")
 
-    (conf, data) = load_data()
+    (conf, data) = config.load_data()
 
     if args.check:
         if wificheck.run_checks():
