@@ -1,7 +1,6 @@
-
-# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -10,11 +9,20 @@
 # or later
 #
 
-import os
 import json
+import os
 from functools import wraps
 
 
+def persist_decorator(klass):
+    """Add a save behavior to methods that update dict data"""
+    for method in ["__setitem__", "__delitem__", "update", "setdefault"]:
+        setattr(klass, method, klass.addsave(getattr(klass, method)))
+
+    return klass
+
+
+@persist_decorator
 class persist(dict):
     """A JSON-file backed persistent dictionary"""
 
@@ -23,49 +31,36 @@ class persist(dict):
 
         super(persist, self).__init__(*args, **kwargs)
 
-        self.__dict__['path'] = path
+        self._path = path
 
-        if os.path.exists(self.path):
+        if os.path.exists(self._path):
             self.load()
 
         self.save()
 
     def save(self):
-        with open(self.path, 'w') as fp:
+        with open(self._path, "w") as fp:
             json.dump(self, fp, indent=2)
 
     def load(self):
-        with open(self.path, 'r') as fp:
-            dict = json.load(fp)
+        with open(self._path, "r") as fp:
+            dct = json.load(fp)
 
-        self.update(dict)
+        super().update(dct)
 
     def addsave(fn):
-        @wraps(fn)
-        def wrapper(inst, *args, **kwargs):
-            # give wrapped function a chance to validate arguments
-            fn(inst, *args, **kwargs)
+        """Decorator to add save behavior to methods"""
 
-            super_method = getattr(inst.__class__.__bases__[0], fn.__name__)
-            retval = super_method(inst, *args, **kwargs)
-            inst.save()
+        @wraps(fn)
+        def wrapper(self, *args, **kwargs):
+            retval = fn(self, *args, **kwargs)
+            self.save()
             return retval
+
         return wrapper
 
-    @addsave
-    def __setitem__(self, key, value, super_ret=None):
-        pass
-
-    @addsave
-    def update(self, *args, **kwargs):
-        pass
-
-    @addsave
-    def setdefault(self, *args, **kwargs):
-        pass
-
     def __setattr__(self, name, value):
-        if name in self.__dict__:
+        if name in self.__dict__ or name.startswith("_"):
             self.__dict__[name] = value
         else:
             self.__setitem__(name, value)
