@@ -1,7 +1,7 @@
 
-# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -11,27 +11,11 @@
 #
 
 import logging
-import dbus
 
-bus = dbus.SystemBus()
-systemd_service = bus.get_object(
-    'org.freedesktop.systemd1',
-    '/org/freedesktop/systemd1',
-)
-
-sd_start_unit = systemd_service.get_dbus_method(
-    'StartUnit',
-    'org.freedesktop.systemd1.Manager',
-)
-
-sd_stop_unit = systemd_service.get_dbus_method(
-    'StopUnit',
-    'org.freedesktop.systemd1.Manager',
-)
+from .sysd import sd_start_unit, sd_stop_unit
 
 log = logging.getLogger('comitup')
 
-
 COMITUP_SERVICE = 'comitup-web.service'
 
 web_service = ""
@@ -50,7 +34,7 @@ def stop_service(service):
 callmatrix = {
     ('HOTSPOT',    'start'): (lambda: stop_service, lambda: web_service),
     ('HOTSPOT',     'pass'): (lambda: start_service, lambda: COMITUP_SERVICE),
-    ('CONNECTING',  'pass'): (lambda: stop_service, lambda: COMITUP_SERVICE),
+    ('CONNECTING', 'start'): (lambda: stop_service, lambda: COMITUP_SERVICE),
     ('CONNECTED',  'start'): (lambda: start_service, lambda: web_service),
 }
 
@@ -73,3 +57,5 @@ def init_webmgr(web_svc):
     global web_service
 
     web_service = web_svc
+
+    log.debug("web service is %s" % web_service)
